@@ -21,7 +21,7 @@ from pytensor.graph.type import HasDataType
 from pytensor.graph.utils import TestValueError
 from pytensor.tensor.basic import AllocEmpty, cast
 from pytensor.tensor.subtensor import set_subtensor
-from pytensor.tensor.var import TensorConstant
+from pytensor.tensor.variable import TensorConstant
 
 
 if TYPE_CHECKING:
@@ -903,7 +903,6 @@ class ScanArgs:
     def _remove_from_fields(
         self, i: Variable, field_filter: Callable[[str], bool] = default_filter
     ) -> Optional[FieldInfo]:
-
         field_info = self.find_among_fields(i, field_filter=field_filter)
 
         if field_info is None:
@@ -940,7 +939,6 @@ class ScanArgs:
 
         dependent_nodes = set()
         for k, v in var_mappings.items():
-
             if not k.endswith(map_key_suffix):
                 continue
 
@@ -993,7 +991,6 @@ class ScanArgs:
     def remove_from_fields(
         self, i: Variable, rm_dependents: bool = True
     ) -> List[Tuple[Variable, Optional[FieldInfo]]]:
-
         if rm_dependents:
             vars_to_remove = self.get_dependent_nodes(i) | {i}
         else:
